==> h5p-7.x-1.16.tar.gz: h5p/modules/h5peditor/h5peditor/language/nb.js <==
H5PEditor.language.core = {
  missingTranslation: '[Mangler oversettelse :key]',
  loading: 'Laster :type, vennligst vent...',
  selectLibrary: 'Velg biblioteket du ønsker å bruke for innholdet ditt.',
  unknownFieldPath: 'Kan ikke finne ":path".',
  notImageField: '":path" er ikke et bilde.',
  notImageOrDimensionsField: '":path" er verken et bilde- eller dimensjonsfelt.',
  requiredProperty: '":property" er påkrevd og må ha en verdi.',
  onlyNumbers: '":property" kan bare innholde tall.',
  exceedsMax: '":property" overstiger maksverdien på :max.',
  belowMin: '":property" er mindre enn minimumsverdien på :min.',
  outOfStep: '":property" kan bare endres i steg på :step.',
  addFile: 'Legg til fil',
  removeFile: 'Fjern fil',
  confirmRemoval: 'Er du sikker på at du ønsker å fjerne denne :type?',
  removeImage: 'Remove image',
  confirmImageRemoval: 'Er du sikker på at du ønsker å fjerne dette bildet?',
  changeFile: 'Bytt fil',
  changeLibrary: 'Endre innholdstype',
  semanticsError: 'Semantikkfeil: :error',
  missingProperty: 'Feltet :index mangler :property attributten sin.',
  expandCollapse: 'Utvid/Slå sammen',
  addEntity: 'Legg til :entity',
  tooLong: 'Feltets verdi er for lang, den må være på :max tegn eller mindre.',
  invalidFormat: 'Feltets verdi er på et ugyldig format eller bruker ulovlige tegn.',
  confirmChangeLibrary: 'Ved å gjøre dette mister du alt arbeid gjort med nåværende innholdstype. Er du sikker på at du ønsker å bytte innholdstype?',
  moreLibraries: 'Se etter <a href="http://h5p.org/content-types-and-applications" target="_blank">flere innholdstyper</a> på h5p.org',
  commonFields: 'Innstillinger og tekster',
  commonFieldsDescription: 'Her kan du redigere innstillinger eller oversette tekster som brukes i dette innholdet.',
  uploading: 'Laster opp fil, vennligst vent...',
  noFollow: 'Kunne ikke følge feltet ":path".',
  editCopyright: 'Rediger opphavsrett',
  close: 'Lukk',
  tutorialAvailable: 'Veiledning tilgjengelig',
  editMode: 'Redigeringsmodus',
  listLabel: 'Liste',
  uploadError: 'Filopplasting feilet',
  fileToLarge: 'Filen du prøver å laste opp kan være for stor.',
  noSemantics: 'Feil, kunne ikke laste skjemaet for innholdstypen.',
  editImage: 'Rediger bilde',
  saveLabel: 'Lagre',
  cancelLabel: 'Avbryt',
  resetToOriginalLabel: 'Tilbakestill bilde',
  loadingImageEditor: 'Laster inn bilderedigering, vennligst vent...'
};

==> h5p-7.x-1.17.tar.gz: h5p/modules/h5peditor/h5peditor/language/nb.js <==
H5PEditor.language.core = {
  missingTranslation: '[Mangler oversettelse :key]',
  loading: 'Laster :type, vennligst vent...',
  selectLibrary: 'Velg biblioteket du ønsker å bruke for innholdet ditt.',
  unknownFieldPath: 'Kan ikke finne ":path".',
  notImageField: '":path" er ikke et bilde.',
  notImageOrDimensionsField: '":path" er verken et bilde- eller dimensjonsfelt.',
  requiredProperty: '":property" er påkrevd og må ha en verdi.',
  onlyNumbers: '":property" kan bare innholde tall.',
  exceedsMax: '":property" overstiger maksverdien på :max.',
  belowMin: '":property" er mindre enn minimumsverdien på :min.',
  outOfStep: '":property" kan bare endres i steg på :step.',
  addFile: 'Legg til fil',
  removeFile: 'Fjern fil',
  confirmRemoval: 'Er du sikker på at du ønsker å fjerne denne :type?',
  removeImage: 'Remove image',
  confirmImageRemoval: 'Er du sikker på at du ønsker å fjerne dette bildet?',
  changeFile: 'Bytt fil',
  changeLibrary: 'Endre innholdstype',
  semanticsError: 'Semantikkfeil: :error',
  missingProperty: 'Feltet :index mangler :property attributten sin.',
  expandCollapse: 'Utvid/Slå sammen',
  addEntity: 'Legg til :entity',
  tooLong: 'Feltets verdi er for lang, den må være på :max tegn eller mindre.',
  invalidFormat: 'Feltets verdi er på et ugyldig format eller bruker ulovlige tegn.',
  confirmChangeLibrary: 'Ved å gjøre dette mister du alt arbeid gjort med nåværende innholdstype. Er du sikker på at du ønsker å bytte innholdstype?',
  moreLibraries: 'Se etter <a href="http://h5p.org/content-types-and-applications" target="_blank">flere innholdstyper</a> på h5p.org',
  commonFields: 'Innstillinger og tekster',
  commonFieldsDescription: 'Her kan du redigere innstillinger eller oversette tekster som brukes i dette innholdet.',
  uploading: 'Laster opp fil, vennligst vent...',
  noFollow: 'Kunne ikke følge feltet ":path".',
  editCopyright: 'Rediger opphavsrett',
  close: 'Lukk',
  tutorialAvailable: 'Veiledning tilgjengelig',
  editMode: 'Redigeringsmodus',
  listLabel: 'Liste',
  uploadError: 'Filopplasting feilet',
  fileToLarge: 'Filen du prøver å laste opp kan være for stor.',
  noSemantics: 'Feil, kunne ikke laste skjemaet for innholdstypen.',
  editImage: 'Rediger bilde',
  saveLabel: 'Lagre',
  cancelLabel: 'Avbryt',
  resetToOriginalLabel: 'Tilbakestill bilde',
  loadingImageEditor: 'Laster inn bilderedigering, vennligst vent...',
  selectFiletoUpload: 'Velg fil som skal lastes opp',
  or: 'eller',
  enterAudioUrl: 'Skriv inn nettadresse til lydkilde',
  enterVideoUrl: 'Skriv inn nettadresse til videokilde eller YouTube-lenke',
  addVideoDescription: 'H5P støtter alle eksterne videokilder på formatene mp4, webm eller ogv, slik som Vimeo Pro, og har støtte for YouTube-lenker.',
  insert: 'Sett inn',
  cancel: 'Avbryt'
};
